==> seleniumbase-1.63.19.tar.gz: seleniumbase-1.63.19/help_docs/ReadMe.md <==
<div><a href="https://github.com/seleniumbase/SeleniumBase"><img src="https://seleniumbase.io/cdn/img/mac_sb_logo_5.png" alt="SeleniumBase" width="304" /></a></div>

<h2><img src="https://seleniumbase.io/img/logo6.png" title="SeleniumBase" width="32" /> Help Docs</h2>

<p align="left">
<a href="https://seleniumbase.io/#python_installation">🚀 Start</a> |
<a href="https://seleniumbase.io/help_docs/customizing_test_runs/">🖥️ CLI</a> |
<a href="https://seleniumbase.io/help_docs/features_list/">🗂️ Features</a>
<br />
<a href="https://seleniumbase.io/examples/ReadMe/">📖 Examples</a> |
<a href="https://seleniumbase.io/help_docs/mobile_testing/">📱 Mobile</a>
<br />
<a href="https://seleniumbase.io/help_docs/syntax_formats/">🔡 Syntax Formats</a> |
<a href="https://seleniumbase.io/integrations/github/workflows/ReadMe/">🤖 CI</a>
<br />
<a href="https://seleniumbase.io/help_docs/method_summary/">📗 API</a> |
<a href="https://seleniumbase.io/examples/example_logs/ReadMe/">📋 Reports</a> |
<a href="https://seleniumbase.io/examples/tour_examples/ReadMe/">🗺️ Tours</a>
<br />
<a href="https://seleniumbase.io/seleniumbase/console_scripts/ReadMe/">💻 Console Scripts</a> |
<a href="https://seleniumbase.io/seleniumbase/utilities/selenium_grid/ReadMe/">🌐 Grid</a>
<br />
<a href="https://github.com/seleniumbase/SeleniumBase/tree/master/examples/boilerplates">♻️ Boilerplates</a> |
<a href="https://seleniumbase.io/help_docs/locale_codes/">🗾 Locales</a>
<br />
<a href="https://seleniumbase.io/help_docs/js_package_manager/">🗄️ PkgManager</a> |
<a href="https://seleniumbase.io/examples/visual_testing/ReadMe/">🖼️ VisualTest</a>
<br />
<a href="https://seleniumbase.io/help_docs/translations/">🌏 Translate</a> |
<a href="https://seleniumbase.io/examples/master_qa/ReadMe/">🛂 MasterQA</a>
<br />
<a href="https://seleniumbase.io/seleniumbase/utilities/selenium_ide/ReadMe/">⏺️ Recorder</a> |
<a href="https://github.com/seleniumbase/SeleniumBase/tree/master/integrations/node_js">🏃 NodeRunner</a>
<br />
<a href="https://seleniumbase.io/examples/presenter/ReadMe/">📑 Presenter</a> |
<a href="https://seleniumbase.io/examples/chart_maker/ReadMe/">📊 ChartMaker</a>
</p>

--------

<h3>Table of Contents (<a href="https://seleniumbase.io">seleniumbase.io</a>)</h3>

<div><a href="https://seleniumbase.io/help_docs/features_list/"><b>Features List</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/customizing_test_runs/"><b>Command Line Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/examples/ReadMe/"><b>Usage Examples</b></a></div>
<div><a href="https://seleniumbase.io/demo_page"><b>Demo Page for Tests</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/how_it_works/"><b>How SeleniumBase Works</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/install_python_pip_git/"><b>Installing Python, Pip, & Git</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/virtualenv_instructions/"><b>Python Virtual Env Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/install/"><b>SeleniumBase Installation</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/webdriver_installation/"><b>Webdriver Installation</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/verify_webdriver/"><b>Verify Webdriver Works</b></a></div>
<div><a href="https://seleniumbase.io/seleniumbase/console_scripts/ReadMe/"><b>Console Scripts Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/syntax_formats/"><b>Syntax Formats</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/mobile_testing/"><b>Mobile Device Testing</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/method_summary/"><b>Method Summary (API Ref)</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/translations/"><b>Language Translations</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/locale_codes/"><b>Language Locale Codes</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/js_package_manager/"><b>JS Package Manager</b></a></div>
<div><a href="https://seleniumbase.io/examples/tour_examples/ReadMe/"><b>Tour Examples</b></a></div>
<div><a href="https://seleniumbase.io/examples/presenter/ReadMe/"><b>Presentation Maker</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/chart_maker/"><b>Chart Maker</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/mysql_installation/"><b>MySQL Installation Overview</b></a></div>
<div><a href="https://seleniumbase.io/seleniumbase/utilities/selenium_grid/ReadMe/"><b>Using the Selenium Grid</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/desired_capabilities/"><b>Browser Desired Capabilities</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/using_safari_driver/"><b>Safari Driver Detailed Info</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/hidden_files_info/"><b>Seeing Hidden Files on macOS</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/happy_customers/"><b>Case Studies</b></a></div>

--------

<h3>Demo Pages / Web Examples</h3>

<div><a href="https://seleniumbase.io/demo_page"><b>Demo Page / Demo Site</b></a></div>
<div><a href="https://seleniumbase.io/tinymce/"><b>TinyMCE Demo Page</b></a></div>
<div><a href="https://seleniumbase.io/devices/"><b>Virtual Device Farm</b></a></div>
<div><a href="https://seleniumbase.io/error_page/"><b>Error Page for Tests</b></a></div>
<div><a href="https://seleniumbase.io/other/presenter.html"><b>Presenter Demo</b></a></div>
<div><a href="https://seleniumbase.io/other/core_presentation.html"><b>Core Presentation</b></a></div>
<div><a href="https://seleniumbase.io/other/chart_presentation.html"><b>Chart Maker Demo</b></a></div>
<div><a href="https://seleniumbase.io/other/py_virtual_envs.html"><b>Python Virtual Envs</b></a></div>

--------

<h3>GitHub Pages (<a href="https://seleniumbase.dev">seleniumbase.dev</a>)</h3>

<div><a href="https://seleniumbase.dev/help_docs/features_list"><b>Features List</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/customizing_test_runs"><b>Command Line Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/examples/"><b>Usage Examples</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/how_it_works"><b>How SeleniumBase Works</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/install_python_pip_git"><b>Installing Python, Pip, & Git</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/virtualenv_instructions"><b>Python Virtual Env Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/install"><b>SeleniumBase Installation</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/webdriver_installation"><b>Webdriver Installation</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/verify_webdriver"><b>Verify Webdriver Works</b></a></div>
<div><a href="https://seleniumbase.dev/seleniumbase/console_scripts/"><b>Console Scripts Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/syntax_formats"><b>Syntax Formats</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/mobile_testing"><b>Mobile Device Testing</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/method_summary"><b>Method Summary (API Ref)</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/translations"><b>Language Translations</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/locale_codes"><b>Language Locale Codes</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/js_package_manager"><b>JS Package Manager</b></a></div>
<div><a href="https://seleniumbase.dev/examples/tour_examples/"><b>Tour Examples</b></a></div>
<div><a href="https://seleniumbase.dev/examples/presenter/"><b>Presentation Maker</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/chart_maker"><b>Chart Maker</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/mysql_installation"><b>MySQL Installation Overview</b></a></div>
<div><a href="https://seleniumbase.dev/seleniumbase/utilities/selenium_grid/"><b>Using the Selenium Grid</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/desired_capabilities"><b>Browser Desired Capabilities</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/using_safari_driver"><b>Safari Driver Detailed Info</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/hidden_files_info"><b>Seeing Hidden Files on macOS</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/happy_customers"><b>Case Studies</b></a></div>

--------

<p align="center"><a href="https://github.com/seleniumbase/SeleniumBase/">
<img src="https://seleniumbase.io/img/sb_logo_10.png" alt="SeleniumBase" width="260" />
</a></p>
<!-- View on GitHub -->

==> seleniumbase-3.5.9.tar.gz: seleniumbase-3.5.9/help_docs/ReadMe.md <==
<h2><img src="https://seleniumbase.io/img/logo6.png" title="SeleniumBase" width="32" /> Help Docs</h2>

<p align="left">
<a href="https://seleniumbase.io/#python_installation">🚁 Start</a> |
<a href="https://github.com/seleniumbase/SeleniumBase/blob/master/examples/example_logs/ReadMe.md">🔵 Dashboard</a>
<br />
<a href="https://seleniumbase.io/help_docs/features_list/">🏰 Features</a> |
<a href="https://seleniumbase.io/help_docs/customizing_test_runs/">🎛️ Options</a>
<br />
<a href="https://seleniumbase.io/examples/ReadMe/">✅ Examples</a> |
<a href="https://seleniumbase.io/help_docs/mobile_testing/">📱 Mobile</a>
<br />
<a href="https://seleniumbase.io/help_docs/syntax_formats/">📝 Formats</a> |
<a href="https://seleniumbase.io/integrations/github/workflows/ReadMe/">🤖 CI/CD</a>
<br />
<a href="https://seleniumbase.io/help_docs/method_summary/">📙 APIs</a> |
<a href="https://seleniumbase.io/examples/example_logs/ReadMe/">📊 Reports</a> |
<a href="https://seleniumbase.io/examples/tour_examples/ReadMe/">🚎 Tours</a>
<br />
<a href="https://seleniumbase.io/seleniumbase/console_scripts/ReadMe/">🔮 Console Scripts</a> |
<a href="https://seleniumbase.io/seleniumbase/utilities/selenium_grid/ReadMe/">🌐 Grid</a>
<br />
<a href="https://github.com/seleniumbase/SeleniumBase/tree/master/examples/boilerplates">♻️ Boilerplates</a> |
<a href="https://seleniumbase.io/help_docs/locale_codes/">🗾 Locales</a>
<br />
<a href="https://seleniumbase.io/help_docs/js_package_manager/">🕹️ JSManager</a> |
<a href="https://seleniumbase.io/examples/visual_testing/ReadMe/">🖼️ VisualTest</a>
<br />
<a href="https://seleniumbase.io/help_docs/translations/">🈺 Translate</a> |
<a href="https://seleniumbase.io/examples/dialog_boxes/ReadMe/">🛂 DialogBoxes</a>
<br />
<a href="https://seleniumbase.io/help_docs/recorder_mode/">🔴 Recorder</a> |
<a href="https://github.com/seleniumbase/SeleniumBase/tree/master/integrations/node_js">🏃 NodeRunner</a>
<br />
<a href="https://seleniumbase.io/examples/presenter/ReadMe/">🎞️ Slides</a> |
<a href="https://seleniumbase.io/examples/chart_maker/ReadMe/">📊 Charts</a>
</p>

--------

<h3>Table of Contents (<a href="https://seleniumbase.io">seleniumbase.io</a>)</h3>

<div><a href="https://seleniumbase.io/help_docs/features_list/"><b>Features List</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/customizing_test_runs/"><b>Command Line Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/examples/ReadMe/"><b>Usage Examples</b></a></div>
<div><a href="https://seleniumbase.io/demo_page"><b>Demo Page for Tests</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/how_it_works/"><b>How SeleniumBase Works</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/install_python_pip_git/"><b>Installing Python, Pip, & Git</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/virtualenv_instructions/"><b>Python Virtual Env Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/install/"><b>SeleniumBase Installation</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/webdriver_installation/"><b>Webdriver Installation</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/verify_webdriver/"><b>Verify Webdriver Works</b></a></div>
<div><a href="https://seleniumbase.io/seleniumbase/console_scripts/ReadMe/"><b>Console Scripts Tutorial</b></a></div>
<div><a href="https://seleniumbase.io/examples/example_logs/ReadMe/"><b>The Dashboard</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/recorder_mode/"><b>Recorder Mode</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/syntax_formats/"><b>Syntax Formats</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/mobile_testing/"><b>Mobile Device Testing</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/method_summary/"><b>Method Summary (API Ref)</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/translations/"><b>Language Translations</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/locale_codes/"><b>Language Locale Codes</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/js_package_manager/"><b>JS Package Manager</b></a></div>
<div><a href="https://seleniumbase.io/examples/tour_examples/ReadMe/"><b>Tour Examples</b></a></div>
<div><a href="https://seleniumbase.io/examples/presenter/ReadMe/"><b>Presentation Maker</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/chart_maker/"><b>Chart Maker</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/mysql_installation/"><b>MySQL Installation Overview</b></a></div>
<div><a href="https://seleniumbase.io/seleniumbase/utilities/selenium_grid/ReadMe/"><b>Using the Selenium Grid</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/desired_capabilities/"><b>Browser Desired Capabilities</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/using_safari_driver/"><b>Safari Driver Detailed Info</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/hidden_files_info/"><b>Seeing Hidden Files on macOS</b></a></div>
<div><a href="https://seleniumbase.io/help_docs/happy_customers/"><b>Case Studies</b></a></div>

--------

<h3>Demo Pages / Web Examples</h3>

<div><a href="https://seleniumbase.io/demo_page"><b>Demo Page (Test Page)</b></a></div>
<div><a href="https://seleniumbase.io/realworld/login"><b>MFA Login (Test Page)</b></a></div>
<div><a href="https://seleniumbase.io/tinymce/"><b>TinyMCE (Test Page)</b></a></div>
<div><a href="https://seleniumbase.io/error_page/"><b>Error Page (Test Page)</b></a></div>
<div><a href="https://seleniumbase.io/other/drag_and_drop"><b>Drag-&-Drop (Test Page)</b></a></div>
<div><a href="https://seleniumbase.io/devices/"><b>Device Farm (Virtual)</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/"><b>HTML Playground Page</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/sbase"><b>SeleniumBase in iframe</b></a></div>
<div><a href="https://seleniumbase.io/other/broken_page"><b>Page with broken links</b></a></div>
<div><a href="https://seleniumbase.io/other/shadow_dom"><b>Shadow DOM/Root</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/iframes"><b>W3Schools iframes</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/file_upload"><b>W3Schools file upload</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/double_click"><b>W3Schools doubleclick</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/drag_drop"><b>W3Schools drag & drop</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/checkboxes"><b>W3Schools checkboxes</b></a></div>
<div><a href="https://seleniumbase.io/w3schools/radio_buttons"><b>W3Schools radio buttons</b></a></div>

--------

<h3>Presentations</h3>

<div><a href="https://seleniumbase.io/other/presenter.html"><b>Presenter Demo</b></a></div>
<div><a href="https://seleniumbase.io/other/core_presentation.html"><b>Core Presentation</b></a></div>
<div><a href="https://seleniumbase.io/other/chart_presentation.html"><b>Chart Maker Demo</b></a></div>
<div><a href="https://seleniumbase.io/other/py_virtual_envs.html"><b>Python Virtual Envs</b></a></div>

--------

<h3>GitHub Pages (<a href="https://seleniumbase.dev">seleniumbase.dev</a>)</h3>

<div><a href="https://seleniumbase.dev/help_docs/features_list"><b>Features List</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/customizing_test_runs"><b>Command Line Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/examples/"><b>Usage Examples</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/how_it_works"><b>How SeleniumBase Works</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/install_python_pip_git"><b>Installing Python, Pip, & Git</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/virtualenv_instructions"><b>Python Virtual Env Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/install"><b>SeleniumBase Installation</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/webdriver_installation"><b>Webdriver Installation</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/verify_webdriver"><b>Verify Webdriver Works</b></a></div>
<div><a href="https://seleniumbase.dev/seleniumbase/console_scripts/"><b>Console Scripts Tutorial</b></a></div>
<div><a href="https://seleniumbase.dev/examples/example_logs/"><b>The Dashboard</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/recorder_mode"><b>Recorder Mode</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/syntax_formats"><b>Syntax Formats</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/mobile_testing"><b>Mobile Device Testing</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/method_summary"><b>Method Summary (API Ref)</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/translations"><b>Language Translations</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/locale_codes"><b>Language Locale Codes</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/js_package_manager"><b>JS Package Manager</b></a></div>
<div><a href="https://seleniumbase.dev/examples/tour_examples/"><b>Tour Examples</b></a></div>
<div><a href="https://seleniumbase.dev/examples/presenter/"><b>Presentation Maker</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/chart_maker"><b>Chart Maker</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/mysql_installation"><b>MySQL Installation Overview</b></a></div>
<div><a href="https://seleniumbase.dev/seleniumbase/utilities/selenium_grid/"><b>Using the Selenium Grid</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/desired_capabilities"><b>Browser Desired Capabilities</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/using_safari_driver"><b>Safari Driver Detailed Info</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/hidden_files_info"><b>Seeing Hidden Files on macOS</b></a></div>
<div><a href="https://seleniumbase.dev/help_docs/happy_customers"><b>Case Studies</b></a></div>

--------

<p align="center"><a href="https://github.com/seleniumbase/SeleniumBase/">
<img src="https://seleniumbase.io/img/sb_logo_10.png" alt="SeleniumBase" width="260" />
</a></p>
<!-- View on GitHub -->
